if __name__ == '__main__':  # pragma: no cover
    import sys

    from stgit.main import main

    sys.exit(main())
